@@ -47,6 +47,15 @@ _TDIARY_HEADER
 <meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
 </head>
 _SPONICHI
+			<<'_TECHNOCRUTY' => NKF::UTF8,
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+
+<head profile="http://gmpg.org/xfn/11">
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+
+<title>TechCrunch Japanese  </title>
+_TECHNOCRUTY
 		}.each_pair do |header, charset|
 			res = HTTPResponse.new( {:HTTPVersion => '1.1'} )
 			res.body = header
@@ -173,8 +182,51 @@ _END
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC-JP"></head>hello',
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC_JP"></head>hello' =>
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC-JP"></head>hello',
-			"<meta http-equiv='Content-Type' content='text/html; charset=UTF-8' />" =>
-			"<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP' />",
+			"<head><meta http-equiv='Content-Type' content='text/html; charset=UTF-8' /></head>" =>
+			"<head><meta http-equiv='Content-Type' content='text/html; charset=EUC-JP' /></head>",
+			<<'_JS_SRC' => <<'_JS_DST',
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html><head>
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
+<meta http-equiv="Content-Script-Type" content="text/javascript; charset=UTF-8">
+<meta http-equiv="content-style-type" content="text/css; charset=UTF-8">
+</head>
+<body>
+<pre><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></pre>
+</body>
+</html>
+_JS_SRC
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<html><head>
+<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
+<meta http-equiv="Content-Script-Type" content="text/javascript; charset=EUC-JP">
+<meta http-equiv="content-style-type" content="text/css; charset=EUC-JP">
+</head>
+<body>
+<pre><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></pre>
+</body>
+</html>
+_JS_DST
+			<<'_TECHCRUNCH_SRC' =>
+<head profile="http://gmpg.org/xfn/11">
+<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+
+<title>TechCrunch Japanese  </title>
+
+</head>
+<body>
+</body>
+_TECHCRUNCH_SRC
+			<<'_TECHCRUNCH_DST'
+<head profile="http://gmpg.org/xfn/11">
+<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP" />
+
+<title>TechCrunch Japanese  </title>
+
+</head>
+<body>
+</body>
+_TECHCRUNCH_DST
 		}.each_pair do |src, dst|
 			res = HTTPResponse.new( {:HTTPVersion => '1.1'} )
 			res.content_type = 'text/html'
@@ -194,9 +246,13 @@ _END
 <!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.0//EN" "http://www.wapforum.org/DTD/xhtml-mobile10.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><title>test</title></head><body><p>hello world</p></body></html>
 _END
 			<<'_END' => <<'_END',	# http://www.radiumsoftware.com/
+<head>
 <meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
+</head>
 _END
+<head>
 <meta http-equiv="content-type" content="application/xhtml+xml; charset=EUC-JP" />
+</head>
 _END
 			<<'_END' => <<'_END',
 <?xml version='1.0' encoding='SHIFT_JIS'?>
